# Example Package

For TEALS homework because asgh all weve done so far has been review why ahhhhh

quickstart:
shell -> pip install tealshwlibrary

Documentation:
June7:
is_prime() - if integer is a prime, return True, else returns False

factorial() - returns factorial of integer

integer_input() - continuously asks user for an integer input, returns the integer

June8:
happy_birthday() - requires a name parameter, prints happy birthday song

pick_cards() - given an integer and any number of lists, returns [integer] amount of random choices from every list


